[GFS2] Fix gfs_ prefix in locking.c

The previous patch didn't change all the gfs_ to gfs2_ so
this is the remainder.

Signed-off-by: Steven Whitehouse <swhiteho@redhat.com>
diff --git a/fs/gfs2/locking.c b/fs/gfs2/locking.c
index 1831928..ded1ef6 100644
--- a/fs/gfs2/locking.c
+++ b/fs/gfs2/locking.c
@@ -31,13 +31,13 @@
 static struct mutex lmh_lock;
 
 /**
  * gfs_register_lockproto - Register a low-level locking protocol
  * @proto: the protocol definition
  *
  * Returns: 0 on success, -EXXX on failure
  */
 
-int gfs_register_lockproto(struct lm_lockops *proto)
+int gfs2_register_lockproto(struct lm_lockops *proto)
 {
 	struct lmh_wrapper *lw;
 
@@ -67,12 +67,12 @@
 }
 
 /**
  * gfs_unregister_lockproto - Unregister a low-level locking protocol
  * @proto: the protocol definition
  *
  */
 
-void gfs_unregister_lockproto(struct lm_lockops *proto)
+void gfs2_unregister_lockproto(struct lm_lockops *proto)
 {
 	struct lmh_wrapper *lw;
 
@@ -117,7 +117,7 @@
 	int try = 0;
 	int error, found;
 
- retry:
+retry:
 	mutex_lock(&lmh_lock);
 
 	found = 0;
@@ -151,7 +151,7 @@
 				     min_lvb_size, flags, lockstruct, fskobj);
 	if (error)
 		module_put(lw->lw_ops->lm_owner);
- out:
+out:
 	mutex_unlock(&lmh_lock);
 	return error;
 }
@@ -186,6 +186,6 @@
 	INIT_LIST_HEAD(&lmh_list);
 }
 
-EXPORT_SYMBOL_GPL(gfs_register_lockproto);
-EXPORT_SYMBOL_GPL(gfs_unregister_lockproto);
+EXPORT_SYMBOL_GPL(gfs2_register_lockproto);
+EXPORT_SYMBOL_GPL(gfs2_unregister_lockproto);
@@ -31,13 +31,13 @@
 
 /**
- * gfs_register_lockproto - Register a low-level locking protocol
+ * gfs2_register_lockproto - Register a low-level locking protocol
  * @proto: the protocol definition
  *
@@ -67,12 +67,12 @@
 
 /**
- * gfs_unregister_lockproto - Unregister a low-level locking protocol
+ * gfs2_unregister_lockproto - Unregister a low-level locking protocol
  * @proto: the protocol definition
  *